==> hasktags-0.73.0-78-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-73LO7tKTWJKBMX6VrmAzIx
key:                  hasktags-0.73.0-73LO7tKTWJKBMX6VrmAzIx
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  6f228c17ff12bface5bcd66f3534d5dd
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-73LO7tKTWJKBMX6VrmAzIx
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 json-0.10-7OgMvq22Eb892gIopNPdIi
    microlens-platform-0.4.4.1-9kCfITkIQW94XaSx1poppx
    utf8-string-1.0.2-EQXJBdOxi5qEemJFLwYYhw

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.73.0-79-x86_64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-HA5kjxepq0E9hdjIHEU9OV
key:                  hasktags-0.73.0-HA5kjxepq0E9hdjIHEU9OV
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  c99a12efe4a9d57e99c7af535482d0c4
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-HA5kjxepq0E9hdjIHEU9OV
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 json-0.10-7OgMvq22Eb892gIopNPdIi
    microlens-platform-0.4.4.1-5r3zLXI8hQqCvBDZVRSgLH
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
